@@ -29,7 +29,7 @@ use Image::ExifTool::IPTC;
 use Image::ExifTool::Canon;
 use Image::ExifTool::Nikon;
 
-$VERSION = '1.68';
+$VERSION = '1.69';
 @ISA = qw(Exporter);
 
 sub NumbersFirst;
@@ -152,9 +152,9 @@ API).
     XMP => q{
 XMP stands for "Extensible Metadata Platform", an XML/RDF-based metadata
 format which is being pushed by Adobe.  Information in this format can be
-embedded in many different image file types including JPG, JP2, TIFF, PNG,
-MIFF, PS, PDF, PSD and DNG, as well as audio file formats supporting ID3v2
-information.
+embedded in many different image file types including JPG, JP2, TIFF, PS,
+PDF, PSD, DNG, PNG, SVG and MIFF, as well as audio file formats supporting
+ID3v2 information.
 
 The XMP B<Tag ID>'s aren't listed because in most cases they are identical
 to the B<Tag Name>.
@@ -290,10 +290,11 @@ RealMedia (RM, RV and RMVB), 2) RealAudio (RA), and 3) Real Metafile (RAM
 and RPM).
 },
     Extra => q{
-The extra tags represent information found in the image but not associated
-with any other tag group.  The three writable "pseudo" tags (Filename,
-Directory and FileModifyDate) may be written without the need to rewrite the
-file since their values are not contained within the file data.
+The extra tags represent extra information extracted or generated by
+ExifTool that is not associated with another tag group.  The three writable
+"pseudo" tags (Filename, Directory and FileModifyDate) may be written
+without the need to rewrite the file since their values are not contained
+within the file data.
 },
     Composite => q{
 The values of the composite tags are derived from the values of other tags.
@@ -352,7 +353,7 @@ sub new
     my (%tagNameInfo, %id, %longID, %longName, %shortName, %tableNum,
         %tagLookup, %tagExists, %tableWritable, %sepTable, %compositeModules);
     $self->{TAG_NAME_INFO} = \%tagNameInfo;
-    $self->{TAG_ID} = \%id;
+    $self->{ID_LOOKUP} = \%id;
     $self->{LONG_ID} = \%longID;
     $self->{LONG_NAME} = \%longName;
     $self->{SHORT_NAME} = \%shortName;
@@ -402,23 +403,18 @@ sub new
         }
         my $tableNum = $tableNum{$tableName};
         my $writeProc = $table->{WRITE_PROC};
+        my $vars = $table->{VARS} || { };
         $longID{$tableName} = 0;
         $longName{$tableName} = 0;
         # save all tag names
         my ($tagID, $binaryTable, $noID, $isIPTC);
         $isIPTC = 1 if $$table{WRITE_PROC} and $$table{WRITE_PROC} eq \&Image::ExifTool::IPTC::WriteIPTC;
-        $noID = 1 if $short =~ /^(Composite|XMP|Extra|Shortcuts|ASF.*)$/ or $table->{VARS}->{NO_ID};
-        if (($table->{VARS} and $table->{VARS}->{INDEX}) or
-            ($table->{PROCESS_PROC} and
-             $table->{PROCESS_PROC} eq \&Image::ExifTool::ProcessBinaryData))
+        $noID = 1 if $short =~ /^(Composite|XMP|Extra|Shortcuts|ASF.*)$/ or $$vars{NO_ID};
+        if ($$vars{ID_LABEL} or ($table->{PROCESS_PROC} and
+            $table->{PROCESS_PROC} eq \&Image::ExifTool::ProcessBinaryData))
         {
             $binaryTable = 1;
-            $id{$tableName} = 'Index';
-        } elsif ($table->{PROCESS_PROC} and
-            $table->{PROCESS_PROC} eq \&Image::ExifTool::Canon::ProcessSerialData)
-        {
-            $binaryTable = 1;
-            $id{$tableName} = 'Sequence';
+            $id{$tableName} = $$vars{ID_LABEL} || 'Index';
         } elsif ($isIPTC and $$table{PROCESS_PROC}) { #only the main IPTC table has a PROCESS_PROC
             $id{$tableName} = 'Record';
         } elsif (not $noID) {
@@ -427,11 +423,9 @@ sub new
         $caseInsensitive = ($tableName =~ /::XMP::/);
         my @keys = sort NumbersFirst TagTableKeys($table);
         my $defFormat = $table->{FORMAT};
-        if (not $defFormat and $table->{PROCESS_PROC} and
-            $table->{PROCESS_PROC} eq \&Image::ExifTool::ProcessBinaryData)
-        {
-            $defFormat = 'int8u';   # use default format for binary data tables
-        }
+        # use default format for binary data tables
+        $defFormat = 'int8u' if not $defFormat and $binaryTable;
+
 TagID:  foreach $tagID (@keys) {
             my ($tagInfo, @tagNames, $subdir, $format, @values);
             my (@infoArray, @require, @writeGroup, @writable);
@@ -996,6 +990,7 @@ sub GetTableOrder()
         Ricoh   => 'Pentax',
         Sanyo   => 'Ricoh',
         PhotoMechanic => 'FotoStation',
+       'Pentax::LensData' => 'Pentax::LensInfo2',
     );
     my @tweak = sort keys %tweakOrder;
     while (@tweak) {
@@ -1148,7 +1143,7 @@ sub WriteTagNames($$)
     my ($self, $podFile, $htmldir) = @_;
     my ($tableName, $short, $url, @sepTables);
     my $tagNameInfo = $self->{TAG_NAME_INFO} or return 0;
-    my $idTitle = $self->{TAG_ID};
+    my $idLabel = $self->{ID_LOOKUP};
     my $shortName = $self->{SHORT_NAME};
     my $sepTable = $self->{SEPARATE_TABLE};
     my $success = 1;
@@ -1292,7 +1287,7 @@ sub WriteTagNames($$)
             next;
         }
         my $info = $$tagNameInfo{$tableName};
-        my $id = $$idTitle{$tableName};
+        my $id = $$idLabel{$tableName};
         my ($hid, $showGrp);
         # widths of the different columns in the POD documentation
         my ($wID,$wTag,$wReq,$wGrp) = (8,36,24,10);
@@ -1368,10 +1363,10 @@ sub WriteTagNames($$)
         $line .= sprintf " %-${wGrp}s", 'Group' if $showGrp;
         $line .= ' Writable';
         print PODFILE $line;
-        $line =~ s/Sequence /Sequence\t/;   # don't want an underline after 'Sequence'
+        $line =~ s/^(\s*\w.{6}\w) /$1\t/;   # change space to tab after long ID label (ie. "Sequence")
         $line =~ s/\S/-/g;
         $line =~ s/- -/---/g;
-        $line =~ tr/\t/ /;
+        $line =~ tr/\t/ /;                  # change tab back to space
         print PODFILE $line,"\n";
         close HTMLFILE;
         OpenHtmlFile($htmldir, $short) or $success = 0;
