@@ -349,7 +349,7 @@ my %id3v2_common = (
     TLEN => {
         Name => 'Length',
         ValueConv => '$val / 1000',
-        PrintConv => '"$val sec"',
+        PrintConv => '"$val s"',
     },
     TMED => 'Media',
     TOAL => 'OriginalAlbum',
@@ -563,6 +563,7 @@ sub WarnOnce($$)
         $exifTool->Warn($warn);
     }
 }
+
 #------------------------------------------------------------------------------
 # Process ID3v2 information
 # Inputs: 0) ExifTool object ref, 1) dirInfo ref, 2) tag table ref
@@ -933,7 +934,7 @@ other types of audio files.
 
 =head1 AUTHOR
 
-Copyright 2003-2007, Phil Harvey (phil at owl.phy.queensu.ca)
+Copyright 2003-2008, Phil Harvey (phil at owl.phy.queensu.ca)
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
